@@ -685,11 +685,11 @@ class PhIDEBase(object):
             return ast_dict
 
         # airflow 运行
-        # self.context = ast_parse(self.context)
-        # self.args = ast_parse(self.args)
-        #
-        # self.s3_job_path = dv.DAGS_S3_PHJOBS_PATH + self.dag_name + "/" + self.job_full_name
-        # self.submit_prefix = "s3a://" + dv.TEMPLATE_BUCKET + "/" + dv.CLI_VERSION + self.s3_job_path + "/"
+        self.context = ast_parse(self.context)
+        self.args = ast_parse(self.args)
+
+        self.s3_job_path = dv.DAGS_S3_PHJOBS_PATH + self.dag_name + "/" + self.job_full_name
+        self.submit_prefix = "s3a://" + dv.TEMPLATE_BUCKET + "/" + dv.CLI_VERSION + self.s3_job_path + "/"
 
         stream = self.phs3.open_object(dv.TEMPLATE_BUCKET, dv.CLI_VERSION + self.s3_job_path + "/phconf.yaml")
         config = PhYAMLConfig()
